@@ -72,6 +72,14 @@ where
         emit!(self, n.block);
     }
 
+    #[emitter]
+    fn emit_qualified_rule_prelude(&mut self, n: &QualifiedRulePrelude) -> Result {
+        match n {
+            QualifiedRulePrelude::SelectorList(n) => emit!(self, n),
+            QualifiedRulePrelude::Invalid(n) => emit!(self, n),
+        }
+    }
+
     #[emitter]
     fn emit_at_rule(&mut self, n: &AtRule) -> Result {
         match n {
@@ -723,8 +731,14 @@ where
                         _ => !self.config.minify,
                     },
                     ComponentValue::Ident(_) => match next {
-                        Some(ComponentValue::SimpleBlock(_))
-                        | Some(ComponentValue::Color(Color::HexColor(_)))
+                        Some(ComponentValue::SimpleBlock(SimpleBlock { name, .. })) => {
+                            if *name == '(' {
+                                true
+                            } else {
+                                !self.config.minify
+                            }
+                        }
+                        Some(ComponentValue::Color(Color::HexColor(_)))
                         | Some(ComponentValue::Str(_)) => !self.config.minify,
                         Some(ComponentValue::Delimiter(_)) => false,
                         Some(ComponentValue::Number(n)) => {
